@@ -9,7 +9,16 @@ from findmydevice.models import Device
 
 @admin.register(Device, site=fmd_admin_site)
 class DeviceModelAdmin(NoAddPermissionsMixin, admin.ModelAdmin):
-    readonly_fields = ('uuid', 'hashed_password', 'privkey', 'pubkey', 'create_dt', 'update_dt')
+    readonly_fields = (
+        'uuid',
+        'hashed_password',
+        'privkey',
+        'pubkey',
+        'user_agent',
+        'command2user',
+        'create_dt',
+        'update_dt',
+    )
     list_display = (
         'uuid',
         'name',
@@ -21,6 +30,17 @@ class DeviceModelAdmin(NoAddPermissionsMixin, admin.ModelAdmin):
     list_filter = ('name',)
     date_hierarchy = 'create_dt'
     ordering = ('-update_dt',)
+    fieldsets = (
+        (_('Device info'), {'fields': ('uuid', 'name', 'user_agent', 'push_url', 'command2user')}),
+        (
+            _('FMD data'),
+            {
+                'classes': ('collapse',),
+                'fields': ('hashed_password', 'privkey', 'pubkey'),
+            },
+        ),
+        (_('Timestamps'), {'fields': ('create_dt', 'update_dt')}),
+    )
 
     @admin.display(description=_('Last Location'))
     def last_location_date(self, obj):
