@@ -1,18 +1,16 @@
 import datetime
 import logging
-import uuid
 
-from bx_django_utils.models.timetracking import TimetrackingBaseModel
 from django.db import models
 
 from findmydevice.models import Device
+from findmydevice.models.base import FmdBaseModel
 
 
 logger = logging.getLogger(__name__)
 
 
-class Location(TimetrackingBaseModel):
-    uuid = models.UUIDField(primary_key=True, default=uuid.uuid4)
+class Location(FmdBaseModel):
     device = models.ForeignKey(Device, on_delete=models.CASCADE)
     bat = models.CharField(max_length=256, unique=True)
     raw_date = models.PositiveBigIntegerField()
