@@ -5,7 +5,7 @@ from django.views import View
 
 from findmydevice.json_utils import parse_json
 from findmydevice.models import Device
-from findmydevice.models.device import get_device_by_token
+from findmydevice.services.device import get_device_by_token
 
 
 logger = logging.getLogger(__name__)
@@ -17,6 +17,12 @@ class DeviceView(View):
     """
 
     def put(self, request):
+        """
+        Register a new Device
+        """
+        user_agent = request.headers.get('User-Agent')
+        logger.info('New device register, user agent: %r', user_agent)
+
         data = parse_json(request)
         hashed_password = data['hashedPassword']
 
@@ -27,6 +33,7 @@ class DeviceView(View):
             hashed_password=hashed_password,
             privkey=data['privkey'],
             pubkey=data['pubkey'],
+            user_agent=user_agent,
         )
         access_token = {'DeviceId': device.uuid, 'AccessToken': ''}
         return JsonResponse(access_token)
