@@ -3,7 +3,7 @@ from django.views import View
 
 from findmydevice.json_utils import parse_json
 from findmydevice.models import Device
-from findmydevice.models.device import get_device_by_token
+from findmydevice.services.device import get_device_by_token
 
 
 class KeyView(View):
