@@ -7,7 +7,7 @@ from django.views import View
 
 from findmydevice.json_utils import parse_json
 from findmydevice.models import Location
-from findmydevice.models.device import get_device_by_token
+from findmydevice.services.device import get_device_by_token
 
 
 logger = logging.getLogger(__name__)
@@ -22,6 +22,9 @@ class LocationView(View):
         """
         Store a new location from device
         """
+        user_agent = request.headers.get('User-Agent')
+        logger.info('Store new location, user agent: %r', user_agent)
+
         location_data = parse_json(request)
 
         bat = location_data['bat']
@@ -61,6 +64,7 @@ class LocationView(View):
                 lat=lat,
                 lon=lon,
                 provider=provider,
+                user_agent=user_agent,
             )
             logger.info('New location stored: %s', location)
         response_data = {
